@@ -327,11 +327,11 @@ def change_bulkstatus_to_string(df):
     if 'BulkStatus' in df:
         logger.info("Changing Bulk Status")
         logger.info(f"{df['BulkStatus'].value_counts()}")
-        df.loc[(df['BulkStatus'] == '2'), 'BulkStatus'] = 'FU'
-        df.loc[(df['BulkStatus'] == '0'), 'BulkStatus'] = 'New'
-        df.loc[(df['BulkStatus'] == '6'), 'BulkStatus'] = 'OOO'
-        df.loc[(df['BulkStatus'] == '12'), 'BulkStatus'] = 'NN'
-        df.loc[~(df['BulkStatus'].isin(['2','0','6','12'])),'BulkStatus'] = 'Other'
+        df.loc[(df['BulkStatus'] == 2), 'BulkStatus'] = 'FU'
+        df.loc[(df['BulkStatus'] == 0), 'BulkStatus'] = 'New'
+        df.loc[(df['BulkStatus'] == 6), 'BulkStatus'] = 'OOO'
+        df.loc[(df['BulkStatus'] == 12), 'BulkStatus'] = 'NN'
+        df.loc[~(df['BulkStatus'].isin([2,0,6,12])),'BulkStatus'] = 'Other'
         logger.info(f"{df['BulkStatus'].value_counts()}")
     return df
 
